/******************************************************************************
 * FILE
 *    uc_spc572l64_cfg.h
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC57
 *    
 * DESCRIPTION:
 *    Default configuration that can be changed by the user either
 *    on command line, here or in bsp_user_cfg.h file (needs to be
 *    enabled by defining BSP_USER_CFG=1 symbol).
 *
 *    Parameters can be changed by defining corresponding symbol without
 *    _DEF appendix.
 *    Example:
 *       User wants to change UC_SYSTEM_CLOCK, he needs to define
 *       #define UC_SYSTEM_CLOCK  X
 *       on command line or in bsp_user_cfg.h file
 *
 * FILE HISTORY:
 *    V1.0    23.09.2017     RO
 *       > Initial version
 *    V2.0    25.01.2018     RO
 *       > file header update
 *    V3.0    30.01.2018     MF
 *    	 > file update for SPC572L64 
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 *
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef _UC_SPC572L64_CFG_H_
#define _UC_SPC572L64_CFG_H_


/* ============================================================================
 * DEFAULT MAIN CLOCK SETTING
 * User ** can ** change it, either externally by defining correct
 * symbol or here in this file
 * ==========================================================================*/

/* XTAL_CLOCK: External crystal clock */
#ifndef UC_XTAL_CLOCK
#define UC_XTAL_CLOCK             40
#endif

/* SYS_CLOCK: System clock for CGM SC dividers (CPUs etc.) [MHz] */
#ifndef UC_SYSTEM_CLOCK
#define UC_SYSTEM_CLOCK           80
#endif


/* ============================================================================
 * DEFAULT uC SETTING
 * User ** should not ** change it unless he is certain what he is doing
 * ==========================================================================*/

/* Platform clocks */
#define UC_PLL0_PHI_CLOCK         80

/* Peripheral clocks */
#define UC_PER_CLK0               80
#define UC_SDADC_CLK              10
#define UC_SARADC_CLK             10
#define UC_FRAY_CLK               40
#define UC_SENT_CLK               80
#define UC_CAN_CLK0               40
#define UC_DSPI_CLK0              80
#define UC_DSPI_CLK1              80


/* SWT Watchdogs Disable */
#define UC_SWT0_DISABLE           0
#define UC_SWT1_DISABLE           0
#define UC_SWT2_DISABLE           1
#define UC_SWT3_DISABLE           1

/* Cores' Cache enable */
#define UC_CORE0_ICACHE_ENABLE    0
#define UC_CORE0_DCACHE_ENABLE    0
#define UC_CORE1_ICACHE_ENABLE    0
#define UC_CORE1_DCACHE_ENABLE    0
#define UC_CORE2_ICACHE_ENABLE    0
#define UC_CORE2_DCACHE_ENABLE    0


/* SYSCLK_1 output */
#define UC_SYSCLK1_ENABLE         1
#define UC_SYSCLK1_SEL            UC_SYSCLK1_SELCTL_PLL0_PHI
#define UC_SYSCLK1_DIV            10



#endif /* UC_SPC572L64_CFG_H */
